{ config, lib, pkgs, inputs, modulesPath, ... }:

{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
    (modulesPath + "/profiles/qemu-guest.nix")
  ];

  boot = {
    initrd.availableKernelModules = [ "xhci_pci" "nvme" "usbhid" "usb_storage" "sd_mod" ];
    initrd.kernelModules = [ ];
#    kernelPackages = pkgs.linuxPackages_hardened;
#    kernelModules = [ "kvm-intel" ];
    loader = {
      systemd-boot = {
        enable = true;
        configurationLimit = 10;
      };
      efi.canTouchEfiVariables = true;
    };
  };

  nix.settings.cores = 3;
  nix.settings.max-jobs = 6;

  # disabling this is what's considered a "Bad Idea"
  # however it is required by packages/ghost.nix, which
  # is borrowed from https://notes.abhinavsarkar.net/2022/ghost-on-nixos
  #
  # i don't know of a cleaner way to do this, and i
  # don't want to deal with ghost any longer than i
  # already have, so This Will Do
  nix.settings.sandbox = false;

  modules.hardware.fs = {
    enable = true;
    ssd.enable = true;
  };

  fileSystems."/" =
    { device = "/dev/disk/by-uuid/a4278811-e227-4dea-b7a2-5eaaab003679";
      fsType = "f2fs";
    };

  fileSystems."/boot" =
    { device = "/dev/disk/by-uuid/688D-5046";
      fsType = "vfat";
    };

  swapDevices =
    [ { device = "/dev/disk/by-uuid/a3611c1a-5d34-484d-9fda-e9af0806b13a"; }
    ];

  powerManagement.cpuFreqGovernor = lib.mkDefault "powersave";

  # Enables DHCP on each ethernet and wireless interface. In case of scripted networking
  # (the default) this is the recommended approach. When using systemd-networkd it's
  # still possible to use this option, but it's recommended to use it in conjunction
  # with explicit per-interface declarations with `networking.interfaces.<interface>.useDHCP`.
  networking.useDHCP = lib.mkDefault true;
  # networking.interfaces.enp0s1.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "aarch64-linux";

}
